/*
 * File:   main.c
 * Author: david
 *
 * Created on 3 de octubre de 2017, 14:07
 */

#pragma config FWDTEN = OFF

#include "xc.h"
#include "stdio.h"
#include "system.h"
#include "adc.h"
#include "timer.h"

extern unsigned char modeSelected;

const char *modeNames[6]={
    "STANDBY",
    "GRIP STRENGTH",
    "SIT-TO-STAND TIME",
    "STAND-TO-SIT TIME",
    "WALK TIME",
    "SYNCHRONIZE DATA"
};

int main(void) {
    
    /* System initialization: pin mapping, comms, sensors, ADC, ... */
    system_Init();
        
    printf("Available modes:\r\n");
    printf("\t0 - Standby (Off)\r\n");
    printf("\t1 - Grip Strength (Red)\r\n");
    printf("\t2 - Sit-to-stand time (Yellow)\r\n");
    printf("\t3 - Stand-to-sit time (Blue)\r\n");
    printf("\t4 - Walk time (Green)\r\n");
    printf("\t5 - Synchronize data (White)\r\n");
    printf("\r\n");
    printf("Current system mode is %s\r\n", modeNames[system_getSystemMode()]);
    printf("..waiting for pressing..\r\n");
    
    /* Main system loop */
    while(1){
        /* Mode selection */
        /* Each time the user presses the ball, the system changes transitions
         * the current mode. But, the mode is not selected until a pause of 5
         * seconds */
        while(!modeSelected || system_getSystemMode()==SYSTEM_STANDBY ){
            /* Detect if the ball is pressed */
            if(adc_read() > 700){
                /* If so, set the targe mode to the next one in the list. */
                system_setSystemMode((system_getSystemMode()+1));
                /* Delay to avoid pressing rebounces. */
                timer2_wait(400);
            }
        }
        
        /* Current selected mode is different than STANDBY and the 5-second
         * timeout has expired. */
        printf("Current system mode is %s\r\n", modeNames[system_getSystemMode()]);
        
        /* According to the selected mode, run the desired functionality. */
        switch(system_getSystemMode()){
            case SYSTEM_GRIP_STRENGTH:
                /* Measure grip strength. */
                system_gripStrength();
                break;
            case SYSTEM_SIT_TO_STAND_TIME:
                /* Measure sit-to-stand time. */
                system_sit2Stand();
                break;
            case SYSTEM_STAND_TO_SIT_TIME:
                /* Measure stand-to-sit time. */
                system_stand2Sit();
                break;
            case SYSTEM_WALK_TIME:
                /* Measure walk time. */
                system_walkTime();
                break;
            case SYSTEM_SYNC_DATA:
                /* Dump out all measurements acquired in current session. */
                system_syncData();
                break;
            default:
                break;
        }
        
        /* Return to STANDBY mode. */
        system_setSystemMode(SYSTEM_STANDBY);
        printf("Current system mode is %s\r\n", modeNames[system_getSystemMode()]);
        printf("..waiting for pressing..\r\n"); 
    }
    
    /* Main will never return. */
    return 0;
}
