/* 
 * File:   MMA7455.h
 * Author: david
 *
 * Created on 24 de septiembre de 2017, 17:05
 */

#ifndef MMA7455_H
#define	MMA7455_H

#ifdef	__cplusplus
extern "C" {
#endif

#define MMA7455_NUMREGISTERS 0x1F     
// Define register address   
#define MMA7455_XOUTL   0x00 // 10 bits output value X LSB
#define MMA7455_XOUTH   0x01 // 10 bits output value X MSB
#define MMA7455_YOUTL   0x02 // 10 bits output value Y LSB
#define MMA7455_YOUTH   0x03 // 10 bits output value Y MSB
#define MMA7455_ZOUTL   0x04 // 10 bits output value Z LSB
#define MMA7455_ZOUTH   0x05 // 10 bits output value Z MSB
#define MMA7455_XOUT8   0x06 // 8 bits output value X
#define MMA7455_YOUT8   0x07 // 8 bits output value Y
#define MMA7455_ZOUT8   0x08 // 8 bits output value Z
#define MMA7455_STATUS  0x09 // Status registers
#define MMA7455_DETSRC  0x0A // Detection source registers
#define MMA7455_TOUT    0x0B // ?Temperature output value? (Optional)
#define MMA7455_I2CAD   0x0D // I2C device address
#define MMA7455_USRINF  0x0E // User information (Optional)
#define MMA7455_WHOAMI  0x0F // ?Who am I? value (Optional)
#define MMA7455_XOFFL   0x10 // Offset drift X value (LSB)
#define MMA7455_XOFFH   0x11 // Offset drift X value (MSB)
#define MMA7455_YOFFL   0x12 // Offset drift Y value (LSB)
#define MMA7455_YOFFH   0x13 // Offset drift Y value (MSB)
#define MMA7455_ZOFFL   0x14 // Offset drift Z value (LSB)
#define MMA7455_ZOFFH   0x15 // Offset drift Z value (MSB)
#define MMA7455_MCTL    0X16 // Mode control
#define MMA7455_INTRST  0x17 // Interrupt latch reset
#define MMA7455_CTL1    0x18 // Control 1
#define MMA7455_CTL2    0x19 // Control 2
#define MMA7455_LDTH    0x1A // Level detection threshold limit value
#define MMA7455_PDTH    0x1B // Pulse detection threshold limit value
#define MMA7455_PW      0x1C // Pulse duration value
#define MMA7455_LT      0x1D // Latency time value
#define MMA7455_TW      0x1E // Time window for 2nd pulse value

/* This method resets the MMA7455 registers. */
void mma7455_reset(void);

/* This method performs the required initial calibration to obtain proper acceleration measurements. */
void mma7455_calibration(void);

/* This method sets the MMA7455 in measurement mode. */
void mma7455_setupMeasurementMode(void);

/* This method is blocking until a freefall is detected in any axis. */
void mma7455_waitFreefall(void);

/* This method prints the value of all MMA7455 registers. */
void mma7455_printRegisters(void);

/* This method prints the current acceleration of all three axis. */
void mma7455_printAxisStatus(void);

/* This method reads the current acceleration in X axis. */
char mma7455_getXAxisAcceleration(void);

/* This method reads the current acceleration in Y axis. */
char mma7455_getYAxisAcceleration(void);

/* This method reads the current acceleration in Z axis. */
char mma7455_getZAxisAcceleration(void);

#ifdef	__cplusplus
}
#endif

#endif	/* MMA7455_H */

