#include "spi.h"
#include "timer.h"

/* This method configures SPI1 module as master in mode 0 with 16-bit data exchange at a baudrate of 50 kbps.  */
void spi1_config(void){
	
    SPI1CON1Lbits.MSTEN = 1; // Master enabled
    SPI1STATLbits.SPIROV = 0; // Clear SPIROV bit
    SPI1CON1Lbits.CKE = 1;
    
    SPI1CON1bits.MODE16 = 1;
    SPI1CON1Lbits.SPIEN = 1; // Enabled module    
    SPI1BRGL = 19;
    
    return;
}

/* This method accesses the 8-bit data contents of a register via its 6-bit address. */
unsigned int spi1_readRegister(unsigned char registerAddress){
	/* In the 16-bit word to be sent, the address is from bit 1 to bit 6 */
    unsigned int tx = (registerAddress << 9);
	/* Enable chip select */
    PORTBbits.RB9 = 0;
    while(SPI1STATLbits.SPITBF){};
    SPI1BUFL = tx; // Output is MSB -> LSB
    while(!SPI1STATLbits.SPIRBF){};
    timer2_wait(10);
	/* Disable chip select */
    PORTBbits.RB9 = 1;
    return SPI1BUFL;
}

/* This method writes 8 bits of data into a register via its 6-bit address. */
void spi1_writeRegister(unsigned char registerAddress, unsigned char registerValue){
	/* In the 16-bit word to be sent, the address is from bit 1 to bit 6.
	 * Data goes from bit 8 to bit 15. Bit 0 set to 1 to indicate write operation */
    unsigned int tx = (registerAddress << 9) | (registerValue) | 0x8000;
    unsigned int dummyRx;
	/* Enable chip select */
    PORTBbits.RB9 = 0;
    while(SPI1STATLbits.SPITBF){};
    SPI1BUFL = tx; // Output is MSB -> LSB
    while(!SPI1STATLbits.SPIRBF){};
    timer2_wait(10);
	/* Disable chip select */
    PORTBbits.RB9 = 1;
    dummyRx = SPI1BUFL;
    
    return;    
}
