#include "timer.h"
#include "led.h"

#define TIMER1_0_5_s_COUNT 15500
#define TIMER1_5_s_COUNT 10

unsigned char counter_5s;
extern unsigned char modeSelected;

/* This method starts a 0.5-second timer for the blinking RGB LED. Indirectly, 
 * the same timer is counting 5 seconds.
 */
void timer1_start(unsigned char mode){
    counter_5s = 0;
    switch(mode){
        case TIMER_MODE_HALF_SECOND:
        {
			/* Reset timer 1 count */
            TMR1 = 0;
			/* Set period for timer 1*/
            PR1 = (unsigned int) TIMER1_0_5_s_COUNT;
			/* Set priority 1 to timer 1 interrupt */
            IPC0bits.T1IP = 1;
			/* Clear timer 1 interrupt flag */
            IFS0bits.T1IF = 0;
			/* Configure timer with a frequency of 31kHz */
            T1CONbits.TCS = 1;
            T1CONbits.T1ECS = 0x2;
            T1CONbits.TCKPS = 0x0;
			/* Start timer 1 */
            T1CONbits.TON = 1;
			/* Enable interrupt for timer 1*/
            IEC0bits.T1IE = 1;
            break;
        }
        default:{
            break;
        }
    }
}

/* This method stops the timer for the blinking RGB LED. */
void timer1_stop(void){
	/* Disable timer 1 interrupt source */
    IPC0bits.T1IP = 0;
	/* Clear timer 1 interrupt flag */
    IFS0bits.T1IF = 0;
	/* Disable interrupt for timer 1*/
    IEC0bits.T1IE = 0;
	/* Reset timer 1 count */
    TMR1 = 0;
	/* Reset timer 1 period */
    PR1 = 0;
	/* Stop timer 1 */
    T1CON = 0;
}

/* This method starts the timer used to measure the time of sit-to-stand, stand-to-sit and walk modes. */
void timer3_start(void){
	/* Reset timer 3 count */
    TMR3 = 0;
	/* Set period to maximum value: 541.6 seconds = 9 minutes */
    PR3 = 0xFFFF;
	/* Configure timer with a frequency of 121 Hz */
    T3CONbits.TCS = 1;
    T3CONbits.TECS = 0x2;
    T3CONbits.TCKPS = 0x3;
	/* Start timer 3 */
    T3CONbits.TON = 1;
}

/* This method stops the timer used to measure the time of sit-to-stand, stand-to-sit and walk modes 
 * and returns the number of counter clock ticks. 
 */
unsigned int timer3_stop(void){
    unsigned int time = 0;
	/* Stop timer 3 */
    T3CONbits.TON = 0;
	/* Get current timer 3 count value */
    time = TMR3;
	/* Reset timer 3 count */
    TMR3 = 0;
    
    return time;
}

/* This method is used to perform delays. */
void timer2_wait(unsigned int ms){
	
	/* Set timeout value = 31 kHz * 0.001 s = 31. Each milisecond is 31 timer counts */
    unsigned int timeout = 31 * ms;
    /* Reset timer 2 count */
    TMR2 = 0;
	/* Set period to maximum value */
    PR2 = 0xFFFF;
	/* Configure timer with a frequency of 31kHz */
    T2CONbits.TCS = 1;
    T2CONbits.TECS = 0x2;
    T2CONbits.TCKPS = 0x0;
	/* Start timer 2*/
    T2CONbits.TON = 1;
    
	/* Wait until timeout is reached */
    while(TMR2 < timeout){};
    
	/* Stop timer 2 */
    T2CONbits.TON = 0;
}

/* This interrupt service routine is used to handle the blinking RGB LED and the 5-second timeout. */
void __attribute__((__interrupt__,auto_psv)) _T1Interrupt(void){
    /* Blinking LED implementation as well as handling 5-second timeout to select mode.*/
    if(counter_5s == (TIMER1_5_s_COUNT-1)){
        counter_5s = 0;
        led_toggle(1);
        modeSelected = 1;
        timer1_stop();
    }else{
        led_toggle((counter_5s & 0x1));
        counter_5s++;
    }
	/* Clear timer 1 interrupt flag */
    IFS0bits.T1IF = 0;
}